@@ -31,7 +31,7 @@ def depart_title(self, node):
                                 html.slide_path(self.builder), aname,) +
                          u'title="%s">%s' % (
                          _('Slides'),
-                         self.builder.app.config.slides_html_slide_link_symbol))
+                         self.builder.app.config.slide_html_slide_link_symbol))
 
         if not close_tag.startswith('</a></h'):
             self.body.append('</a>')
@@ -47,6 +47,20 @@ class SlideTranslator(HTMLTranslator):
 
         self.section_count = 0
 
+    def visit_slideconf(self, node):
+        pass
+
+    def depart_slideconf(self, node):
+        pass
+
+    def _add_slide_number(self, slide_no):
+        """Add the slide number to the output if enabled."""
+
+        if self.builder.config.slide_numbers:
+            self.body.append(
+                '\n<div class="slide-no">%s</div>\n' % (slide_no,),
+            )
+
     def visit_section(self, node):
 
         self.section_count += 1
@@ -62,6 +76,11 @@ class SlideTranslator(HTMLTranslator):
             if self.section_level > 1 and not getattr(node.parent, 'closed', False):
                 # close the previous slide
                 node.parent.closed = True
+
+                # substract 1 from the section count since we had an
+                # implicit start to the next section (usually from
+                # sub-sections being made into slides).
+                self._add_slide_number(self.section_count - 1)
                 self.body.append('\n</article>\n')
 
             node.closed = False
@@ -75,6 +94,7 @@ class SlideTranslator(HTMLTranslator):
             self.body.append('</div>')
         else:
             if not getattr(node, 'closed', False):
+                self._add_slide_number(self.section_count)
                 self.body.append('</article>\n')
 
         self.section_level -= 1
@@ -87,7 +107,7 @@ class SlideTranslator(HTMLTranslator):
             self.body.append(self.starttag(node, tag, ''))
             self.context.append('</%s>\n' % tag)
         else:
-            HTMLTranslator.visit_subtitle(self, node)
+            HTMLTranslator.visit_title(self, node)
 
     def depart_title(self, node):
 
@@ -99,6 +119,6 @@ class SlideTranslator(HTMLTranslator):
                                         html.html_path(self.builder), aname,) +
                                  u'title="%s">%s</a>' % (
                                  _('View HTML'),
-                                 self.builder.app.config.slides_html_slide_link_symbol))
+                                 self.builder.app.config.slide_html_slide_link_symbol))
 
         HTMLTranslator.depart_title(self, node)
